ArrayableVariableTrait

Trait ArrayableVariableTrait 

pub trait ArrayableVariableTrait: AbstractVariableTrait {
    // Required methods
    fn dimensions(&self) -> &[Dimension];
    fn add_dimensions(&mut self, dims: &[Dimension]);
    fn intermediate_update(&self) -> Option<bool>;
    fn previous(&self) -> Option<u32>;
}

Required Methods

fn dimensions(&self) -> &[Dimension]

Each Dimension element specifies the size of one dimension of the array

fn add_dimensions(&mut self, dims: &[Dimension])

Extend the dimensions of the variable

fn intermediate_update(&self) -> Option<bool>

If true, the variable can be updated during intermediate update mode.

fn previous(&self) -> Option<u32>

The value reference of the variable that provides the previous value of this variable.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors